pub fn decrypt_data_unsecured(
data: Vec<u8>,
credentials: Credentials,
) -> Result<Vec<u8>, Error>Expand description
Decrypts the data using the provided credentials
This is the same as decrypt_data but returns an unsecure Vec
Use this if the data you want to decrypt is too large to fit in a SecureBytes
Arguments
data- The data to decryptcredentials- The credentials to use for decryption